# compas_3gs

``compas_3gs`` is a 3D graphic statics add-on package for the **COMPAS** framework.


## Getting Started

``compas_3gs`` can be installed directly from the GitHub repo:

    $ pip install git+https://github.com/BlockResearchGroup/compas_3gs.git

Or by cloning it from the URL above using a free Git client such as [Sourcetree](https://www.sourcetreeapp.com/).


## First Steps

* [Theoretical background](https://compas-dev.github.io/compas_3gs/theoretical_background.html)
* [Examples](https://compas-dev.github.io/compas_3gs/examples.html)
* [API reference](https://compas-dev.github.io/compas_3gs/api_reference.html)


## Issue tracker

If you find a bug, please help us solve it by [filing a report](https://github.com/BlockResearchGroup/compas_3gs/issues).


## Contributing

If you want to contribute, check out the [contribution guidelines](https://blockresearchgroup.github.io/compas_3gs/contribution.html).


## License

The ``compas_3gs`` add-on package for **COMPAS** is [released under the MIT license](https://blockresearchgroup.github.io/compas_3gs/license.html).


## Contact

For any questions, suggestions or feedback, please conact the main contributor of ``compas_3gs``, Juney Lee, via email: juney.lee@arch.ethz.ch.